@@ -1,26 +1,20 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
- * 2010, 2011 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000-2015 BalaBit IT Ltd, Budapest, Hungary
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 as published
- * by the Free Software Foundation.
- *
- * Note that this permission is granted for only version 2 of the GPL.
- *
- * As an additional exemption you are allowed to compile & link against the
- * OpenSSL libraries as published by the OpenSSL project. See the file
- * COPYING for details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  ***************************************************************************/
 
@@ -34,11 +28,13 @@
 #include <zorp/pydict.h>
 #include <zorp/dispatch.h>
 #include <zorp/poll.h>
-#include <zorp/audit.h>
 #include <zorp/thread.h>
 #include <zorp/proxyssl.h>
+#include <zorp/pyencryption.h>
 
 
+#include <glib.h>
+
 /* proxy states, the order of these enums is important */
 enum
 {
@@ -52,7 +48,7 @@ enum
 };
 
 /* proxy flags */
-enum 
+enum
 {
   ZPF_NONBLOCKING=0x0001,
   ZPF_STOP_REQUEST=0x0002,
@@ -79,9 +75,9 @@ enum
 #define Z_VAR_TYPE_INT64        0x00000B00      /* variable is an int64 */
 
 /** The authentication type of z_proxy_user_authenticated() (#ZProxy.userAuthenticated()), indicating which type of authentication
- * occured before calling z_proxy_user_authenticated(). Its "auth_info" parameter is also changed
+ * occurred before calling z_proxy_user_authenticated(). Its "auth_info" parameter is also changed
  */
-typedef enum _ZProxyUserAuthType
+enum ZProxyUserAuthType
 {
   Z_PROXY_USER_AUTHENTICATED_NONE,               /**< The auth type is not explicitly specified, none of the others.
                                                   *  From Zorp, the auth_info parameter is "none", from Python this can be any other, too
@@ -89,16 +85,19 @@ typedef enum _ZProxyUserAuthType
   Z_PROXY_USER_AUTHENTICATED_INBAND,             /**< The authentication is an inband authentication. Auth_info param is "inband". */
   Z_PROXY_USER_AUTHENTICATED_GATEWAY,       /**< The authentication is a gateway authentication. Auth_info param is "gw-auth". */
   Z_PROXY_USER_AUTHENTICATED_SERVER,             /**< The authentication is a server-side authentication. Auth_info param is "server". */
-} ZProxyUserAuthType;
+};
 
-typedef struct _ZProxyParams ZProxyParams;
-typedef struct _ZProxyIface ZProxyIface;
-typedef struct _ZProxyFuncs ZProxyFuncs;
-typedef struct _ZProxyGroup ZProxyGroup;
-typedef struct _ZChannelProps ZChannelProps;
+struct ZProxyModuleFuncs;
+struct ZProxyParams;
+struct ZProxyIface;
+struct ZProxyFuncs;
+struct ZProxyGroup;
+struct ZChannelProps;
+struct ZProxy;
 
-struct _ZProxyParams
+struct ZProxyParams
 {
+public:
   const gchar *session_id;
   ZPolicyObj *pyclient;
   ZStream *client;
@@ -106,8 +105,9 @@ struct _ZProxyParams
   ZProxy *parent;
 };
 
-struct _ZProxyFuncs
+struct ZProxyFuncs
 {
+public:
   ZObjectFuncs super;
   gboolean (*config)(ZProxy *self);
   gboolean (*startup)(ZProxy *self);
@@ -119,13 +119,19 @@ struct _ZProxyFuncs
   void (*wakeup)(ZProxy *self);
 };
 
-struct _ZChannelProps
+#define Z_PROXY_FUNCS_FOR_AUDIT(a, b, c)
+
+#define Z_PROXY_SERVER_SOCKET_MARK 0x40000000
+
+struct ZChannelProps
 {
+public:
   guint8 tos[EP_DIR_MAX];
 };
 
-struct _ZProxy
+struct ZProxy
 {
+public:
   ZObject super;
   gchar session_id[MAX_SESSION_ID];
   ZThread *proxy_thread;
@@ -139,54 +145,66 @@ struct _ZProxy
   ZStream *endpoints[EP_MAX];
   ZPolicyObj *py_endpoints[EP_MAX];
 
+  int server_socket_mark;
   GString *language;
+  GString *alerting_config;
 
   /* a pointer to the parent proxy */
   ZProxy *parent_proxy;
   /* the linked list of child proxies */
   GList *child_proxies;
 
-  GStaticMutex interfaces_lock;  
+  GMutex interfaces_lock;
   GList *interfaces;
 
-  ZProxySsl ssl_opts;
 
   gboolean channel_props_set[EP_MAX];
   ZChannelProps channel_props[EP_MAX];
+
+  ZPolicyEncryption *encryption;
+  ZProxyTls tls_opts;
 };
 
 extern ZClass ZProxy__class;
 
 /* function prototypes registered in the registry */
 typedef ZProxy *(*ZProxyCreateFunc)(ZProxyParams *params);
+typedef void (*ZProxyModulePyInitFunc)(void);
+
+struct ZProxyModuleFuncs
+{
+public:
+  ZProxyCreateFunc create_proxy;
+  ZProxyModulePyInitFunc module_py_init;
+};
 
 /* log functions */
-#define z_proxy_log(self, class, level, format, args...) 		\
+#define z_proxy_log(self, class_, level, format, args...) 		\
   do {									\
     z_object_check_compatible((ZObject *) self, Z_CLASS(ZProxy));	\
     /*NOLOG*/ 								\
-    z_log(((ZProxy *) self)->session_id, class, level, format,  ##args);	\
+    z_log(((ZProxy *) self)->session_id, class_, level, format,  ##args);	\
   } while (0)
 
-#define z_proxy_log_data_dump(self, class, level, buf, len)             \
+#define z_proxy_log_data_dump(self, class_, level, buf, len)             \
   do {									\
     z_object_check_compatible((ZObject *) self, Z_CLASS(ZProxy));	\
     /*NOLOG*/ 								\
-    z_log_data_dump(((ZProxy *)self)->session_id, class, level, buf, len); \
+    z_log_data_dump(((ZProxy *)self)->session_id, class_, level, buf, len); \
   } while (0)
 
-#define z_proxy_pktbuf_data_dump(self, class, level, pktbuf)             \
+#define z_proxy_pktbuf_data_dump(self, class_, level, pktbuf)             \
   do {									\
     z_object_check_compatible((ZObject *) self, Z_CLASS(ZProxy));	\
     /*NOLOG*/ 								\
-    z_pktbuf_data_dump(((ZProxy *)self)->session_id, class, level, pktbuf); \
+    z_pktbuf_data_dump(((ZProxy *)self)->session_id, class_, level, pktbuf); \
   } while (0)
 
-#define z_proxy_log_text_dump(self, class, level, buf, len)             \
+#define z_proxy_log_text_dump(self, class_, level, buf, len)             \
   do {									\
     z_object_check_compatible((ZObject *) self, Z_CLASS(ZProxy));	\
     /*NOLOG*/ 								\
-    z_log_text_dump(((ZProxy *)self)->session_id, class, level, buf, len); \
+    z_log_text_dump(((ZProxy *)self)->session_id, class_, level, buf, len); \
   } while (0)
 
 #if ENABLE_TRACE
@@ -203,6 +221,9 @@ typedef ZProxy *(*ZProxyCreateFunc)(ZProxyParams *params);
 
 #define z_proxy_return(self, ...)      do { z_proxy_leave(self); return __VA_ARGS__; } while (0)
 
+void z_proxy_report_policy_abort(ZProxy *self);
+void z_proxy_report_invalid_policy(ZProxy *self);
+
 /* interface support */
 void z_proxy_add_iface(ZProxy *self, ZProxyIface *iface);
 void z_proxy_del_iface(ZProxy *self, ZProxyIface *iface);
@@ -212,7 +233,7 @@ ZProxyIface *z_proxy_find_iface(ZProxy *self, ZClass *compat);
 gboolean z_proxy_policy_config(ZProxy *);
 gboolean z_proxy_policy_startup(ZProxy *);
 void z_proxy_policy_shutdown(ZProxy *);
-void z_proxy_policy_destroy(ZProxy *self); 
+void z_proxy_policy_destroy(ZProxy *self);
 
 /* compatibility functions for ZPolicyDict based attribute handling */
 void z_proxy_var_new(ZProxy *self, const gchar *name, guint flags, ...);
@@ -228,7 +249,6 @@ gboolean z_proxy_set_server_address(ZProxy *self, const gchar *host, gint port);
 gint z_proxy_connect_server(ZProxy *self, const gchar *host, gint port);
 gint z_proxy_user_authenticated(ZProxy *self, const gchar *entity, gchar const **groups, ZProxyUserAuthType type);
 
-
 /** Wrapper for z_proxy_user_authenticated() with the default #Z_PROXY_USER_AUTHENTICATED_INBAND parameter.
  * @see z_proxy_user_authenticated()
  */
@@ -239,13 +259,13 @@ z_proxy_user_authenticated_default(ZProxy *self, const gchar *entity, gchar cons
 }
 
 gboolean
-z_proxy_get_addresses(ZProxy *self, 
+z_proxy_get_addresses(ZProxy *self,
                       guint *protocol,
                       ZSockAddr **client_address, ZSockAddr **client_local,
                       ZSockAddr **server_address, ZSockAddr **server_local,
                       ZDispatchBind **client_listen);
 gboolean
-z_proxy_get_addresses_locked(ZProxy *self, 
+z_proxy_get_addresses_locked(ZProxy *self,
                              guint *protocol,
                              ZSockAddr **client_address, ZSockAddr **client_local,
                              ZSockAddr **server_address, ZSockAddr **server_local,
@@ -255,67 +275,73 @@ gboolean z_proxy_threaded_start(ZProxy *self, ZProxyGroup *group);
 gboolean z_proxy_nonblocking_start(ZProxy *self, ZProxyGroup *group);
 void z_proxy_nonblocking_stop(ZProxy *self);
 
-
 gboolean z_proxy_check_license(ZProxy *self);
 
 static inline gboolean
 z_proxy_stop_requested(ZProxy *self)
 {
-  return self->flags & ZPF_STOP_REQUEST; 
+  return self->flags & ZPF_STOP_REQUEST;
+}
+
+static inline void
+z_proxy_clear_stop_request(ZProxy *self)
+{
+  self->flags &= ~ZPF_STOP_REQUEST;
 }
 
 gboolean z_proxy_loop_iteration(ZProxy *self);
 
+
 /* constructor for ZProxy */
 ZProxy *
-z_proxy_new(ZClass *class, ZProxyParams *params);
+z_proxy_new(ZClass *class_, ZProxyParams *params);
 
 /* free method for ZProxy */
 void z_proxy_free_method(ZObject *s);
 
 static inline gboolean
 z_proxy_config(ZProxy *self)
-{ 
+{
   return Z_FUNCS(self, ZProxy)->config(self);
 }
 
 static inline gboolean
 z_proxy_startup(ZProxy *self)
-{ 
+{
   return Z_FUNCS(self, ZProxy)->startup(self);
 }
 
 static inline void
 z_proxy_main(ZProxy *self)
-{ 
+{
   Z_FUNCS(self, ZProxy)->main(self);
 }
 
 static inline void
 z_proxy_shutdown(ZProxy *self)
-{ 
+{
   Z_FUNCS(self, ZProxy)->shutdown(self);
 }
 
 static inline void
 z_proxy_destroy(ZProxy *self)
-{ 
+{
   Z_FUNCS(self, ZProxy)->destroy(self);
 }
 
 static inline gboolean
 z_proxy_nonblocking_init(ZProxy *self, ZPoll *poll)
-{ 
+{
   return Z_FUNCS(self, ZProxy)->nonblocking_init(self, poll);
 }
 
 static inline void
 z_proxy_nonblocking_deinit(ZProxy *self)
-{ 
+{
   Z_FUNCS(self, ZProxy)->nonblocking_deinit(self);
 }
 
-static inline void 
+static inline void
 z_proxy_wakeup(ZProxy *self)
 {
   Z_FUNCS(self, ZProxy)->wakeup(self);
@@ -327,7 +353,7 @@ z_proxy_ref(ZProxy *self)
   return (ZProxy *) z_object_ref(&self->super);
 }
 
-static inline void 
+static inline void
 z_proxy_unref(ZProxy *self)
 {
   z_object_unref(&self->super);
@@ -345,9 +371,10 @@ z_proxy_get_state(ZProxy *self)
   return self->status & 0xFF;
 }
 
-/* Root class for proxy specific interfaces */
-struct _ZProxyIface
+/* Root class_ for proxy specific interfaces */
+struct ZProxyIface
 {
+public:
   ZObject super;
   ZProxy *owner;
 };
@@ -355,7 +382,7 @@ struct _ZProxyIface
 typedef ZObjectFuncs ZProxyIfaceFuncs;
 extern ZClass ZProxyIface__class;
 
-ZProxyIface *z_proxy_iface_new(ZClass *class, ZProxy *proxy);
+ZProxyIface *z_proxy_iface_new(ZClass *class_, ZProxy *proxy);
 void z_proxy_iface_free_method(ZObject *s);
 
 /* ZProxyBasicIface */
@@ -363,15 +390,16 @@ void z_proxy_iface_free_method(ZObject *s);
 /* NOTE: this interface is implemented by all proxies. dynamic references to
  * self->parent should only be used through this interface as in this case it
  * is ensured that the parent proxy exists by the time it is referenced.
- */ 
+ */
 
-typedef ZProxyIface ZProxyBasicIface; 
-typedef struct _ZProxyBasicIfaceFuncs 
+typedef ZProxyIface ZProxyBasicIface;
+struct ZProxyBasicIfaceFuncs
 {
+public:
   ZObjectFuncs super;
   gboolean (*get_var)(ZProxyBasicIface *self, const gchar *var_name, gchar **value);
   gboolean (*set_var)(ZProxyBasicIface *self, const gchar *var_name, gchar *value);
-} ZProxyBasicIfaceFuncs;
+};
 
 extern ZClass ZProxyBasicIface__class;
 
@@ -388,19 +416,20 @@ z_proxy_basic_iface_set_var(ZProxyBasicIface *self, const gchar *var_name, gchar
 }
 
 
-ZProxyBasicIface *z_proxy_basic_iface_new(ZClass *class, ZProxy *proxy);
+ZProxyBasicIface *z_proxy_basic_iface_new(ZClass *class_, ZProxy *proxy);
 #define z_proxy_basic_iface_free_method z_proxy_iface_free_method
 
 /* ZProxyStackIface */
 
 typedef ZProxyIface ZProxyStackIface;
-typedef struct _ZProxyStackIfaceFuncs 
+struct ZProxyStackIfaceFuncs
 {
+public:
   ZObjectFuncs super;
   void (*set_verdict)(ZProxyStackIface *self, ZVerdict verdict, const gchar *description);
   gboolean (*get_content_hint)(ZProxyStackIface *self, gint64 *content_length, const gchar **content_format);
   void (*set_content_hint)(ZProxyStackIface *self, gint64 content_length);
-} ZProxyStackIfaceFuncs;
+};
 
 extern ZClass ZProxyStackIface__class;
 
@@ -432,11 +461,12 @@ z_proxy_stack_iface_get_content_hint(ZProxyStackIface *self, gint64 *content_len
 #define z_proxy_stack_iface_free_method z_proxy_iface_free_method
 
 typedef ZProxyIface ZProxyHostIface;
-typedef struct _ZProxyHostIfaceFuncs
+struct ZProxyHostIfaceFuncs
 {
+public:
   ZObjectFuncs super;
   gboolean (*check_name)(ZProxyHostIface *s, const gchar *host_name, gchar *reason_buf, gsize reason_len);
-} ZProxyHostIfaceFuncs;
+};
 
 extern ZClass ZProxyHostIface__class;
 
@@ -448,8 +478,8 @@ z_proxy_host_iface_check_name(ZProxyHostIface *s, const gchar *host_name, gchar
 
 gboolean z_proxy_stop_request(const gchar *session_id);
 
-
 void z_proxy_hash_init(void);
 void z_proxy_hash_destroy(void);
 
+
 #endif
