@@ -1,31 +1,21 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
- * 2010, 2011 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000-2015 BalaBit IT Ltd, Budapest, Hungary
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License version 2 as published
- * by the Free Software Foundation.
- *
- * Note that this permission is granted for only version 2 of the GPL.
- *
- * As an additional exemption you are allowed to compile & link against the
- * OpenSSL libraries as published by the OpenSSL project. See the file
- * COPYING for details.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Author  : Bazsi
- * Auditor : 
- * Last audited version:
- * Notes:
  *
  ***************************************************************************/
 
@@ -37,7 +27,7 @@
 
 typedef struct _ZPolicyDict ZPolicyDict;
 
-typedef enum 
+typedef enum
 {
   Z_VT_NONE     = 0,    /* end of argument list */
   Z_VT_INT,	        /* variable is an int */
@@ -56,6 +46,7 @@ typedef enum
   Z_VT_DIMHASH,         /* variable is a multidimensional hash */
   Z_VT_ALIAS,	        /* variable is an alias of another variable */
   Z_VT_PTR,             /* variable is a generic pointer */
+  Z_VT_BYTEARRAY,       /* variable is a byte array, representing data possibly containing \0 */
 } ZVarType;
 
 enum
@@ -99,4 +90,3 @@ void z_policy_dict_unref(ZPolicyDict *self);
 void z_policy_dict_destroy(ZPolicyDict *self);
 
 #endif
-
